<?php

define("TIMEOUT", 2.0);

require 'ARlib.inc';

function set($gateway, $attrName, $attrValue, $mote)
{
    $url = "http://" . $gateway . "/gw/rest/V1/?method=gw.getWSDL";
    $proxy = new SoapClient($url);
    $value = new stdClass();
    $value->name = $attrName;
    $value->{$attrName} = $attrValue;
    $ret = $proxy->attributesSet($attrName, $mote, TIMEOUT, "*", $value);
    foreach ($ret as $result) {
        $value = $result->value;
        echo "Mote " . $result->addr . ": " . $attrName .
            " value is " . $value->{$value->name} ."\n";
    }
}

function compareTuple($a, $b) {
    return strcmp($a->name, $b->name);
}

function convertReading($reading, $type) {
     switch ($type) {
     case 'Temperature' : $val = $reading*0.01; return "$val F";
     case 'Humidity'    : $val = $reading*0.01; return "$val %";
     case 'LightTSR'    : $val = $reading; return "$val lux";
     case 'LightPAR'    : $val = $reading; return "$val lux";
     default : return "$reading cts";
     }
}

function get($gateway, $ip, $newSamplePeriod)
{
    $url = "http://" . $gateway . "/gw/rest/V1/?method=gw.getWSDL";
    $proxy = new SoapClient($url);

    $inets = $proxy->inetDump(); // timestamp is heatbeat

    $euid  = IPv4toEUID($inets,$ip);
    $nodes = $proxy->metadataGet(DEFAULTADDR,"name");
    $node  = findNode($nodes,$euid);
    $name  = $node->value;

    echo "Name: " . $name . "\n";
    echo "IP address: " . $ip . "\n";
    echo "EUID: " . $euid . "\n";

    /* Node's timestamp is when metadata lastupdated */
    $hbeat  = date(DATE_RFC822,$node->timestamp);
    echo "Last configured at $hbeat \n";

    /* Get list of sensors present on node */
    $UIDevents=$proxy->eventsList();
    $sensors = GetReadEvents($UIDevents->events);
    usort($sensors,"strcmp");
    //pprint_r($sensors);

    /* Get most recent reading for each sensor. */
    foreach($sensors as $sensor) {
      $reading=$proxy->eventsReadLast($sensor, $euid);
      $sensorType=substr($sensor,0,strlen($sensor)-9);
      if (!empty($reading->results)) {
        $timestamp=$reading->results[0]->timestamp;
        $time=date(DATE_RFC822,$timestamp);
        $valueObj=$reading->results[0]->value;
        $value=$valueObj->{$sensor};
        $realValue=convertReading($value,$sensorType);

        echo "Sensor Type: $sensorType \n";
        echo "Real Value:  $realValue \n";
        echo "Time:        $time \n";
      }
    }

    /* Get Sample Period for node from server */
    $sampleObj=$proxy->eventsReadLast("SamplePeriod", $euid);
    $samplePeriod=$sampleObj->results[0]->value->SamplePeriod;
    echo "Sample Period: $samplePeriod \n";

    if ($newSamplePeriod != 0) {
      set($gateway, "SamplePeriod", $newSamplePeriod, $euid);
    }
}

if ($argc != 3 && $argc != 4) {
    echo "Usage: php node.php gateway node-ip [sample-period]\n";
    exit(3);
}

$gateway = $argv[1];
$ip = $argv[2];

if ($argc == 4) {
  $newSamplePeriod = $argv[3];
}
else {
  $newSamplePeriod = 0;
}
get($gateway, $ip, $newSamplePeriod);
?>
